using System;
using System.Net;

namespace PageBoxGrid
{
	/// <summary>
	/// <p>Ip address and port wrapper.
	/// See <a href="http://pagebox.net/grid.html">Grid</a> for explanations.</p>
	/// <p>Copyright (c) 2002 Alexis Grandemange<br/>
	/// Mail: alexis.grandemange@pagebox.net</p>
	/// <pre>This program is free software; you can redistribute it and/or
	/// modify it under the terms of the GNU Lesser General Public
	/// License as published by the Free Software Foundation; version
	/// 2.1 of the License.
	/// This library is distributed in the hope that it will be useful,
	/// but WITHOUT ANY WARRANTY; without even the implied warranty of
	/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	/// GNU Lesser General Public License for more details.
	/// A copy of the GNU Lesser General Public License lesser.txt should be
	/// included in the distribution.</pre>
	/// </summary>
	public class UDPAddressPort
	{
		/// <summary>
		/// IP address
		/// </summary>
		public string addr = "";
		/// <summary>
		/// UDP port
		/// </summary>
		public int port = 0;
		/// <summary>
		/// Hash code of the contenation of addr and port.
		/// </summary>
		private int hashCode = 0;

		/// <summary>
		/// Constructor. Set member variables.
		/// </summary>
		/// <param name="addr">IP address</param>
		/// <param name="port">UDP port</param>
		public UDPAddressPort(string addr, int port)
		{
			this.addr = addr;
			this.port = port;
		}

		/// <summary>
		/// Default constructor.
		/// </summary>
		public UDPAddressPort() 
		{
		}

		/// <summary>
		/// Overriden GetHashCode - Needed because UDPAddressPort is the key of servers
		/// </summary>
		/// <returns>hashcode of the concatenated fields</returns>
		public override int GetHashCode() 
		{
			if (hashCode == 0) 
			{
				string uap = addr + ":" + port;
				hashCode = uap.GetHashCode();
			}
			return hashCode;
		}

		/// <summary>
		/// Overriden Equals - Needed because UDPAddressPort is the key of servers
		/// </summary>
		/// <param name="uap">Other object</param>
		/// <returns>Return true if UDPAddressPort and addr, port have the same value</returns>
		public override bool Equals(object uap) 
		{
			if (!(uap is UDPAddressPort))
				return false;
			UDPAddressPort uap2 = (UDPAddressPort)uap;
			if (uap2.addr.Equals(addr) && (uap2.port == port))
				return true;
			else
				return false;
		}
	}
}
